/***************************************************
* SECURITY GROUP
****************************************************/
resource "aws_security_group" "db" {
  name        = "main_rds_sg"
  description = "Allow all inbound traffic"
  vpc_id      = "${var.vpc_id}"

  ingress {
    from_port   = 5432
    to_port     = 5432
    protocol    = "TCP"
    cidr_blocks = ["0.0.0.0/0"]
  }

  egress {
    from_port   = 0
    to_port     = 0
    protocol    = "-1"
    cidr_blocks = ["0.0.0.0/0"]
  }
}

/***************************************************
* RDS Postgresql Database
****************************************************/
resource "aws_db_instance" "postgresql" {
    identifier = "db-${var.stack_name}"
    allocated_storage = "${var.rds_allocated_storage}"
    engine = "postgres"
    engine_version = "${var.rds_engine_version}"
    instance_class = "${var.rds_instance_class}"
    name = "nuxeo"
    username = "${var.database_user}"
    password = "${var.database_password}"
    vpc_security_group_ids = ["${aws_security_group.db.id}"]
    db_subnet_group_name = "${aws_db_subnet_group.postgresql.id}"
    parameter_group_name = "default.postgres9.4"
    multi_az = "${var.rds_is_multi_az}"
    storage_type = "${var.rds_storage_type}"
    tags {
      Name = "${var.stack_name} - Nuxeo Postgres Database"
      billing-category = "customers"
      billing-subcategory = "${var.stack_name}"
      role= "nuxeo.db"
    }
	lifecycle {
	    prevent_destroy = false
	}
}

resource "aws_db_subnet_group" "postgresql" {
  name        = "${var.stack_name}-db-subnet-group"
  description = "RDS private subnet group"
  subnet_ids  = ["${var.db_subnets}"]
}
